package cz.aprar.bonitoo.inference;

import ml.dmlc.xgboost4j.java.XGBoostError;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import java.io.IOException;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import static java.util.Collections.emptyList;
import static org.testng.Assert.assertEquals;

public class CacheInferenceTest {
    private static final ZoneId UTC = ZoneId.of("UTC");
    private static final ZonedDateTime TEST_DATE = ZonedDateTime.of(2019, 10, 10, 0, 0, 0, 0, UTC);

    private CacheInference ci;

    @BeforeClass
    void setUp() throws IOException, XGBoostError {
        final ClassLoader classLoader = getClass().getClassLoader();
        ci = new CacheInference(classLoader.getResourceAsStream("model/xgboost-model.bin"),
                classLoader.getResourceAsStream("model/encoder.json"));
    }

    @Test
    void testInference() throws XGBoostError {
        final FlightData[] input = {new FlightData(
                "WS",
                toList("2020-05-09T23:59:00", "2020-05-10T10:30:00"),
                toList("2020-05-10T08:55:00", "2020-05-10T11:30:00"),
                toList("MCO", "FRA"),
                toList("FRA", "PRG"),
                toList("LH", "LH"),
                "LH",
                toList("2020-05-01T09:50:00", "2020-05-01T11:55:00"),
                toList("2020-05-01T11:00:00", "2020-05-01T21:55:00"),
                toList("PRG", "FRA"),
                toList("FRA", "MCO"),
                toList("LH", "LH"),
                "LH",
                39766.0,
                7,
                ZonedDateTime.of(2020, 5, 1, 9, 50, 0, 0, UTC)
        ),
                new FlightData(
                        "PYTON",
                        "",
                        "",
                        "",
                        "",
                        "",
                        "",
                        toList("2019-12-18T05:45:00"),
                        toList("2019-12-18T08:05:00"),
                        toList("KRK"),
                        toList("BVA"),
                        toList("FR"),
                        "FR",
                        336.258,
                        0,
                        ZonedDateTime.of(2019, 12, 18, 5, 45, 0, 0, UTC)
                ),
                new FlightData(
                        "AVIA",
                        toList("2020-02-07T02:25:00", "2020-02-07T14:50:00"),
                        toList("2020-02-07T13:10:00", "2020-02-07T16:55:00"),
                        toList("LAX", "LHR"),
                        toList("LHR", "PRG"),
                        toList("AA", "BA"),
                        "AA",
                        toList("2020-01-28T10:35:00", "2020-01-28T14:40:00"),
                        toList("2020-01-28T12:45:00", "2020-01-29T01:45:00"),
                        toList("PRG", "HEL"),
                        toList("HEL", "LAX"),
                        toList("AY", "AY"),
                        "AY",
                        5971.77978,
                        4,
                        ZonedDateTime.of(2020, 1, 28, 10, 35, 0, 0, UTC)
                ),
                new FlightData(
                        "HH",
                        toList("2019-11-01T16:30:00", "2019-11-01T23:35:00"),
                        toList("2019-11-01T21:12:00", "2019-11-02T07:45:00"),
                        toList("YVR", "YUL"),
                        toList("YUL", "VIE"),
                        toList("LH", "LH"),
                        "LH",
                        toList("2019-10-18T08:10:00", "2019-10-18T11:30:00"),
                        toList("2019-10-18T09:40:00", "2019-10-18T21:25:00"),
                        toList("VIE", "FRA"),
                        toList("FRA", "YVR"),
                        toList("LH", "LH"),
                        "LH",
                        17723.0,
                        12,
                        ZonedDateTime.of(2019, 10, 18, 8, 10, 0, 0, UTC)
                ),
                new FlightData(
                        "unknown",
                        toList(ZonedDateTime.now().format(DateTimeFormatter.ISO_LOCAL_DATE_TIME)),
                        toList(ZonedDateTime.now().format(DateTimeFormatter.ISO_LOCAL_DATE_TIME)),
                        toList("unknown"),
                        toList("unknown"),
                        toList("unknown"),
                        "unknown",
                        toList(ZonedDateTime.now().format(DateTimeFormatter.ISO_LOCAL_DATE_TIME)),
                        toList(ZonedDateTime.now().format(DateTimeFormatter.ISO_LOCAL_DATE_TIME)),
                        toList("unknown"),
                        toList("unknown"),
                        toList("unknown"),
                        "unknown",
                        0.0,
                        0,
                        ZonedDateTime.now()
                )};
        final TTL[] expected = {TTL.D3, TTL.D14, TTL.D2, TTL.D2, TTL.D1};

        final TTL[] result = ci.cacheTTL(input, TEST_DATE);
        assertEquals(result, expected);
    }

    private String toList(final String... data) {
        return String.join("|", data);
    }
}
